@@ -10,6 +10,8 @@ import pickle
 from datetime import date
 from datetime import datetime
 from datetime import timedelta
+from unittest import mock
+from urllib.parse import urlparse
 
 import caldav
 import icalendar
@@ -35,15 +37,6 @@ from caldav.objects import FreeBusy
 from caldav.objects import Journal
 from caldav.objects import Principal
 from caldav.objects import Todo
-from six import PY3
-
-
-if PY3:
-    from urllib.parse import urlparse
-    from unittest import mock
-else:
-    from urlparse import urlparse
-    import mock
 
 ## Some example icalendar data partly copied from test_caldav.py
 ev1 = """BEGIN:VCALENDAR
@@ -263,14 +256,11 @@ class TestCalDAV:
         assert response.status == 200
         assert response.tree is None
 
-        if PY3:
-            response = client.put(
-                "/foo/møøh/bar".encode("utf-8"),
-                "bringebærsyltetøy 北京 пиво".encode("utf-8"),
-                {},
-            )
-        else:
-            response = client.put(u"/foo/møøh/bar", "bringebærsyltetøy 北京 пиво", {})  # fmt: skip
+        response = client.put(
+            "/foo/møøh/bar".encode("utf-8"),
+            "bringebærsyltetøy 北京 пиво".encode("utf-8"),
+            {},
+        )
         assert response.status == 200
         assert response.tree is None
 
@@ -1185,3 +1175,19 @@ END:VCALENDAR
         cal_url = "http://me:hunter2@calendar.example:80/"
         with DAVClient(url=cal_url) as client_ctx_mgr:
             assert isinstance(client_ctx_mgr, DAVClient)
+
+    def testExtractAuth(self):
+        """
+        ref https://github.com/python-caldav/caldav/issues/289
+        """
+        cal_url = "http://me:hunter2@calendar.example:80/"
+        with DAVClient(url=cal_url) as client:
+            assert client.extract_auth_types("Basic\n") == ["basic"]
+            assert client.extract_auth_types("Basic") == ["basic"]
+            assert client.extract_auth_types('Basic Realm=foo;charset="UTF-8"') == [
+                "basic"
+            ]
+            assert client.extract_auth_types("Basic,dIGEST Realm=foo") == [
+                "basic",
+                "digest",
+            ]
